# $Id: $
import os
import sys
import sconstools

from sconstools.PkgConfig import checkPkgConfig

# A SCons test to  look for the FLTK 2 headers  and libs.  Should work
# for the following environments:
# - Mingw32;
# - Linux.
def checkFltk2 (context):
    oldLIBS = context.env["LIBS"]
    if sys.platform != "win32":
        checkPkgConfig (context, "fontconfig")  or context.env.PrependUnique (LIBS = "fontconfig")
        checkPkgConfig (context, "x11")         or context.env.PrependUnique (LIBS = "X11")
        checkPkgConfig (context, "xext")        or context.env.PrependUnique (LIBS = "Xext")
        checkPkgConfig (context, "xft")         or context.env.PrependUnique (LIBS = "Xft")
        checkPkgConfig (context, "xi")          or context.env.PrependUnique (LIBS = "Xi")
        checkPkgConfig (context, "xinerama")    or context.env.PrependUnique (LIBS = "Xinerama")
    context.Message ("Checking for FLTK 2...")
    sconstools.setLibVariables (context.env, "Fltk2")
    if sys.platform == "win32":
        context.env.PrependUnique (LIBS = [ "fltk2", "comdlg32", "gdi32",
                                            "msimg32", "ole32", "uuid",
                                            "wsock32"
                                            ])
    else:
        context.env.PrependUnique (LIBS = [ "fltk2", "pthread", "m", "supc++" ])
    hasFltk2 = context.TryLink ("""
#include <fltk/run.h>
int main (int argc, char* argv[]) {
   fltk::args (argc, argv);
   return 0;
}
""", ".cc")
    context.Result (hasFltk2)
    if not hasFltk2:
        context.env["LIBS"] = oldLIBS
    return hasFltk2

# A SCons test to look for the FLTK 2 images headers and libs.  Should work
# for the following environments:
# - Mingw32;
# - Linux.
def checkFltk2Images (context):
    oldLIBS = context.env["LIBS"]
    if sys.platform != "win32":
        checkPkgConfig (context, "libpng")      or context.env.PrependUnique (LIBS = "png")
        checkPkgConfig (context, "xrender")     or context.env.PrependUnique (LIBS = "Xrender")
    context.Message ("Checking for FLTK 2 Images library...")
    sconstools.setLibVariables (context.env, "Fltk2")
    if sys.platform == "win32":
        context.env.PrependUnique (LIBS = [ "fltk2_images" ])
    else:
        context.env.PrependUnique (LIBS = [ "fltk2_images", "jpeg" ])
    hasFltk2Images = context.TryLink ("""
#include <fltk/SharedImage.h>
int main (int argc, char* argv[]) {
   fltk::register_images();
   return 0;
}
""", ".cc")
    context.Result (hasFltk2Images)
    if not hasFltk2Images:
        context.env["LIBS"] = oldLIBS
    return hasFltk2Images

# Add the tests to those available in a SCons Configure object.
def addTests (conf, vars = None):
    if vars:
        sconstools.addLibVariables (vars, "Fltk2", "Path to the FLTK 2 library")
    conf.AddTests ({ "CheckFltk2":          checkFltk2,
                     "CheckFltk2Images":    checkFltk2Images })
