# $Id: OpenGL.py 2 2006-09-15 11:01:05Z jberger $
import os
import sys

# A SCons test to  look for the OpenGL headers  and libs.  Should work
# for the following environments:
# - Windows (tested with mingw32);
# - Linux X11R6 (tested on Mandriva 2006.0);
# - Linux Xorg 7 (tested on Mandriva 2007.0).
def checkOpenGL (context):
    context.Message ("Checking for OpenGL...")
    oldLIBS = context.env["LIBS"]
    if sys.platform == "win32":
        context.env.Prepend (LIBS = "opengl32")
    else:
        context.env.Prepend (LIBS = "GL")
        if os.path.exists ("/usr/X11R6/lib"):
            context.env.Prepend (LIBPATH = "/usr/X11R6/lib")
    hasOpenGL = context.TryLink ("""
#include <GL/gl.h>
int main (int argc, char* argv[]) {
  glEnable (GL_DEPTH_TEST);
  return 0;
}
""", ".c")
    context.Result (hasOpenGL)
    if not hasOpenGL:
        context.env["LIBS"] = oldLIBS
    return hasOpenGL

# A SCons test to  look for the GLU headers  and libs.  Should work
# for the following environments:
# - Windows (tested with mingw32)
# - Linux Xorg 7 (tested on Mandriva 2007.0).
def checkGLU (context):
    context.Message ("Checking for GLU...")
    oldLIBS = context.env["LIBS"]
    if sys.platform == "win32":
        context.env.Prepend (LIBS = "glu32")
    else:
        context.env.Prepend (LIBS = "GLU")
    hasGLU = context.TryLink ("""
#include <GL/glu.h>
int main (int argc, char* argv[]) {
  gluGetString (GLU_VERSION);
  return 0;
}
""", ".c")
    context.Result (hasGLU)
    if not hasGLU:
        context.env["LIBS"] = oldLIBS
    return hasGLU
    
# Add the tests to those available in a SCons Configure object.
def addTests (conf):
    conf.AddTests ({ "CheckOpenGL": checkOpenGL,
                     "CheckGLU": checkGLU
                     })
