# $Id: $
import os
import sys
import sconstools

# A SCons test to  look for the SDL headers  and libs.  Should work
# for the following environments:
# - Linux Xorg 7 (tested on Mandriva 2007.0).
def checkSDL (context):
    context.Message ("Checking for SDL...")
    env = context.env
    oldLIBS = env["LIBS"]
    sconstools.setLibVariables (env, "SDL")
    sdlConfig = env.get ("sdl_config", "no")
    if sdlConfig != 'no':
        env.ParseConfig ("%s --cflags --libs" % sdlConfig)
    else:
        if sys.platform == "win32":
            env.Append (LIBS = [ "mingw32", "SDLmain", "SDL" ])
        elif (sdlConfig != "no") and env.WhereIs ("sdl-config"):
            env.ParseConfig ("sdl-config --cflags --libs")
        else:
            env.Append (LIBS = [ "SDLmain", "SDL" ])
    hasSDL = context.TryLink ("""
#include <SDL/SDL.h>
int main (int argc, char* argv[]) {
  SDL_Init (SDL_INIT_EVERYTHING);
  return 0;
}
""", ".c")
    context.Result (hasSDL)
    if not hasSDL:
        env["LIBS"] = oldLIBS
    return hasSDL

# A SCons test to  look for the SDL_image headers  and libs.  Should work
# for the following environments:
# - Linux Xorg 7 (tested on Mandriva 2007.0).
def checkSDLImage (context):
    context.Message ("Checking for SDL_Image...")
    oldLIBS = context.env["LIBS"]
    if sys.platform == "win32":
        raise Exception, "SDL Test not implemented for win32"
    else:
        context.env.Append (LIBS = [ "SDL_image" ])
    hasSDLImage = context.TryLink ("""
#include <SDL_image.h>
int main (int argc, char* argv[]) {
  IMG_Load ("test.jpg");
  return 0;
}
""", ".c")
    context.Result (hasSDLImage)
    if not hasSDLImage:
        context.env["LIBS"] = oldLIBS
    return hasSDLImage

# Add the tests to those available in a SCons Configure object.
def addTests (conf, vars = None):
    if vars:
        sconstools.addLibVariables (vars, "SDL", "Path to the SDL library")
        vars.Add ("sdl_config", "Path to the sdl-config script or 'no' if we mustn't use it")
    conf.AddTests ({ "CheckSDL": checkSDL,
                     "CheckSDLImage": checkSDLImage
                     })
