# $Id: plib.py 20 2006-09-21 11:40:54Z jberger $
import os
import sys
import sconstools

# Setup paths from variables
def setLibVariables (env):
    if not env.Dictionary().has_key ("PLIB-set"):
        sconstools.setLibVariables (env, "PLIB")
        env.Dictionary()["PLIB-set"] = True

# Check for the PLIB Font library
def checkPLibFnt (context):
    context.Message ("Checking for PLIB fnt...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibfnt")
    hasPUI = context.TryLink ("""
#include <plib/fnt.h>
int main (int, char*) {
  fntInit();
  return 0;
}
""", ".cc")
    context.Result (hasPUI)
    if not hasPUI:
        context.env["LIBS"] = oldLIBS
    return hasPUI

# Check for the PLIB Network library
def checkPLibNet (context):
    context.Message ("Checking for PLIB net...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibnet")
    if sys.platform == "win32":
        context.env.Append (LIBS = "wsock32")
    hasNET = context.TryLink ("""
#include <plib/net.h>
int main (int, char*) {
  netInit();
  return 0;
}
""", ".cc")
    context.Result (hasNET)
    if not hasNET:
        context.env["LIBS"] = oldLIBS
    return hasNET

# Check for the PLIB Picoscopic User Interface library
def checkPLibPui (context):
    context.Message ("Checking for PLIB pui...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibpu")
    hasPUI = context.TryLink ("""
#define PU_USE_NONE
#include <plib/pu.h>
int main (int, char*) {
  puRealInit();
  return 0;
}
""", ".cc")
    context.Result (hasPUI)
    if not hasPUI:
        context.env["LIBS"] = oldLIBS
    return hasPUI

# Check for the PLIB Windowing library
def checkPLibPw (context):
    context.Message ("Checking for PLIB pw...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibpw")
    if sys.platform == "win32":
        context.env.Append (LIBS = "gdi32")
    hasPW = context.TryLink ("""
#include <plib/pw.h>
int main (int, char*) {
  pwInit (false, 0);
  return 0;
}
""", ".cc")
    context.Result (hasPW)
    if not hasPW:
        context.env["LIBS"] = oldLIBS
    return hasPW

# Check for the PLIB Simple Geometry library
def checkPLibSg (context):
    context.Message ("Checking for PLIB sg...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibsg")
    hasSG = context.TryLink ("""
#include <plib/sg.h>
int main (int, char*) {
  sgVec2 dst;
  sgZeroVec2 (dst);
  return 0;
}
""", ".cc")
    context.Result (hasSG)
    if not hasSG:
        context.env["LIBS"] = oldLIBS
    return hasSG

# Check for the PLIB Simple Scene Graph library
def checkPLibSsg (context):
    context.Message ("Checking for PLIB ssg...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibssg")
    hasSSG = context.TryLink ("""
#include <plib/ssg.h>
int main (int, char*) {
  ssgInit();
  return 0;
}
""", ".cc")
    context.Result (hasSSG)
    if not hasSSG:
        context.env["LIBS"] = oldLIBS
    return hasSSG

# Check for the PLIB SSG Auxilliary library
def checkPLibSsgAux (context):
    context.Message ("Checking for PLIB ssgAux...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibssgaux")
    hasSSGAux = context.TryLink ("""
#include <plib/ssgAux.h>
int main (int, char*) {
  return 0;
}
""", ".cc")
    context.Result (hasSSGAux)
    if not hasSSGAux:
        context.env["LIBS"] = oldLIBS
    return hasSSGAux

# Check for the PLIB Utility library
def checkPLibUl (context):
    context.Message ("Checking for PLIB ul...")
    oldLIBS = context.env["LIBS"]
    setLibVariables (context.env)
    context.env.Prepend (LIBS = "plibul")
    if sys.platform == "win32":
        context.env.Append (LIBS = "winmm")
    hasUL = context.TryLink ("""
#include <plib/ul.h>
int main (int, char*) {
  ulInit();
  return 0;
}
""", ".cc")
    context.Result (hasUL)
    if not hasUL:
        context.env["LIBS"] = oldLIBS
    return hasUL

# Add the tests to those available in a SCons Configure object.
def addTests (conf, vars = None):
    if vars:
        sconstools.addLibVariables (vars, "PLIB", "Path to the PLIB library")
    conf.AddTests ({ "CheckPlibFnt": checkPLibFnt,
                     "CheckPlibNet": checkPLibNet,
                     "CheckPlibPui": checkPLibPui,
                     "CheckPlibPw": checkPLibPw,
                     "CheckPlibSg": checkPLibSg,
                     "CheckPlibSsg": checkPLibSsg,
                     "CheckPlibSsgAux": checkPLibSsgAux,
                     "CheckPlibUl": checkPLibUl
                     })
