import os
import re

from term import TerminalController
term = TerminalController()

# Check for a package using pkg-config and update the environment if
# the package is present
def configPkg (env, package, minVersion = None, maxVersion = None, exactVersion = None):
    pkgConfig = env.WhereIs ("pkg-config")
    if not pkgConfig:
       return False
    pkgConfigPath = env.get ("pkg_config_path", '')
    if pkgConfigPath != '':
        if not env.get ("pkg_config_path_set", False):
            os.environ["PKG_CONFIG_PATH"] = "%s%s%s" % (pkgConfigPath,
                                                        os.pathsep,
                                                        os.environ.get ("PKG_CONFIG_PATH", ""))
            env["pkg_config_path_set"] = True
    if os.spawnl (os.P_WAIT, pkgConfig, "pkg-config", "--exists", package) == 0:
        if minVersion:
            if os.spawnl (os.P_WAIT, pkgConfig,
                          "pkg-config", "--atleast-version=%s" % minVersion,
                          package) != 0:
                return False
        if maxVersion:
            if os.spawnl (os.P_WAIT, pkgConfig,
                          "pkg-config", "--max-version=%s" % maxVersion,
                          package) != 0:
                return False
        if exactVersion:
            if os.spawnl (os.P_WAIT, pkgConfig,
                          "pkg-config", "--exact-version=%s" % exactVersion,
                          package) != 0:
                return False
        env.MergeFlags (os.popen ("pkg-config %s --cflags --libs" % package).read())
        return "v" + os.popen ("pkg-config %s --modversion" % package).read().strip()
    else:
        return False

# Add the variables for a library to the given SCons variables set
def addLibVariables (vars, name, comment):
    vars.AddVariables ((name, comment),
                       ("%s_inc" % name, "%s (includes)" % comment),
                       ("%s_lib" % name, "%s (libs)" % comment))

# Setup the build variables to reflect the given variables
def setLibVariables (env, name):
    cpppath = None
    libpath = None
    if env.Dictionary().has_key (name):
        cpppath = [ os.path.join (env[name], "include") ]
        libpath = [ os.path.join (env[name], "lib") ]
    if env.Dictionary().has_key ("%s_inc" % name):
        cpppath = [ env["%s_inc" % name] ]
    if env.Dictionary().has_key ("%s_lib" % name):
        libpath = [ env["%s_lib" % name] ]
    if cpppath:
        env.AppendUnique (CPPPATH = cpppath)
    if libpath:
        env.AppendUnique (LIBPATH = libpath)

# Print a message
def printMessage (title, msg):
    from sys import stderr
    print >>stderr, "******************************"
    print >>stderr, "*** %s ***" % title.center (22)
    print >>stderr, "******************************"
    print >>stderr, msg
    print >>stderr

# Scan a folder for files matching a given regular expression
def scanFolder (path, regexp = re.compile ("\\.c(c|pp|xx)?$")):
    return [ f
             for f in os.listdir (path)
             if re.search (regexp, f) ]

# Add a variable and setup an environment to use the mpatrol memory
# debugger
def setupMPatrol (vars, env, extraLibs = []):
    from SCons.Variables import BoolVariable
    vars.Add (BoolVariable ("mpatrol",
                            "Enable the mpatrol memory debugger",
                            False))
    vars.Update (env)

    if env["mpatrol"]:
        env.Append (LIBS = [ "mpatrol" ] + extraLibs)

# Create a colored verbose command string
def makeVerboseCommandString (message, command):
    bold   = term.BOLD
    green  = term.GREEN
    normal = term.NORMAL
    yellow = term.YELLOW
    return "%(bold)s%(green)s * %(normal)s%(bold)s%(message)s\n%(normal)s%(yellow)s%(command)s%(normal)s" % \
           locals()

# Create a colored standard command string
def makeStandardCommandString (message):
    bold   = term.BOLD
    green  = term.GREEN
    normal = term.NORMAL
    return "%(bold)s%(green)s * %(normal)s%(bold)s%(message)s%(normal)s" % locals()
