import gdc
import sconstools as tools

def setVariables (env, vars = None):
    print "Setting D variables"
    gdc.generate (env)

    if env["optim"] == "debug":
        env.Append (DFLAGS = [ "-O0", "-g" ])
    elif env["optim"] == "speed":
        env.Append (DFLAGS = [ "-Os", "-fomit-frame-pointer", "-frelease",
                               "$CCFLAGS_TUN", "$CCFLAGS_ARCH" ])
    elif env["optim"] == "size":
        env.Append (DFLAGS = [ "-O3", "-fomit-frame-pointer", "-frelease",
                               "$CCFLAGS_TUN", "$CCFLAGS_ARCH" ])
    elif env["optim"] != "custom":
        raise Exception, "Unknown optimization variable!"

    if not env["verbose"]:
        env["DCOMSTR"] = tools.makeStandardCommandString ("Compiling ${TARGET} from D...")
    else:
        env["DCOMSTR"] = tools.makeVerboseCommandString ("Compiling ${TARGET} from D with:",
                                                         "${DCOM}")

    if not (vars is None):
        from SCons.Variables import BoolVariable
        vars.Add (BoolVariable ("d_unittests", "Enable the D unit tests", False))
        vars.Update (env)

        if env["d_unittests"]:
            env.Append (DFLAGS = [ "-funittest" ])

def unitTests (env, module, sources):
    if env["d_unittests"]:
        def makeTestMain (env, target, source):
            output = file (str (target[0]), "w")
            print >>output, "module test; import %s; void main() {}" % module
            output.close()
        action = env.Action (makeTestMain,
                             tools.makeStandardCommandString ("Creating the main test source file for %s..."
                                                              % module))
        main = env.Command ("test-%s.d" % module, None, action)
        env.Depends (main, env.Value (module))
        prog = env.Program (module, sources + [ main ])
        action = env.Action (prog[0].path,
                             tools.makeStandardCommandString ("Running the D unit tests for %s..." % module))
        env.AlwaysBuild (env.Command ("%s-test" % module, prog, action))
