# $Id: $
import os
import sconstools as tools

from SCons.Action import Action

# Add the rules for gettext translations.
#
# Example:
#
# pot = myEnv.PotBuild ("#po/${PACKAGE}.pot", sources)
# for po in sconstools.scanFolder (os.path.join (baseDir, "po"), "\\.po$"):
#     lang = os.path.splitext (po)[0]
#     gmo = myEnv.MoBuild ("%s.gmo" % lang, os.path.join ("po", po))
#     myEnv.Depends (gmo, pot)
#     env.InstallAs (os.path.join (installPath, "share", "locale",
#                                  lang, "LC_MESSAGES", "${PACKAGE}.mo"),
#                    gmo)
def gettextize (env):
    poAction = Action ("${POCOM}", "${POCOMSTR}")
    moAction = Action ("${MOCOM}", "${MOCOMSTR}")
    potAction = Action ("${POTCOM}", "${POTCOMSTR}")

    env.Append (BUILDERS = {
        'MoBuild': env.Builder (action = [ poAction, moAction ]),
        'PotBuild': env.Builder (action = potAction)
        })

    env["_join"] = os.path.join
    env["POCOM"] = 'msgmerge --update ${SOURCE.srcpath} ${SOURCE.srcdir}/${PACKAGE}.pot'
    env["MOCOM"] = 'msgfmt -c -o $TARGET ${SOURCE.srcpath}'
    env["POTCOM"] = 'xgettext --keyword=_ --keyword=N_ --keyword=P_:1c,2 --from-code=utf-8 -o $TARGET $SOURCES'

    if env["verbose"]:
        env["POCOMSTR"] = tools.makeVerboseCommandString ("Updating translations ${SOURCE.srcpath} with:",
                                                          "$POCOM")
        env["MOCOMSTR"] = tools.makeVerboseCommandString ("Building translations ${TARGET.file} with:",
                                                          "$MOCOM")
        env["POTCOMSTR"] = tools.makeVerboseCommandString ("Extracting i18n strings to ${TARGET.file} with:",
                                                           "$POTCOM")
    else:
        env["POCOMSTR"] = tools.makeStandardCommandString ("Updating translations ${SOURCE.srcpath}...")
        env["MOCOMSTR"] = tools.makeStandardCommandString ("Building translations ${TARGET.file}...")
        env["POTCOMSTR"] = tools.makeStandardCommandString ("Extracting i18n strings to ${TARGET.file}...")
