import os
import re

import SCons

import sconstools as tools

def setVariables (env, vars):
    # Setup compiler variables
    env["CCFLAGS_CMN"] = [ "-Wall", "--pedantic", "-Wextra", "-Wno-long-long", "-pipe" ]
    env["CCFLAGS_ANS"] = [ "-ansi" ]
    env["CCFLAGS_DBG"] = [ "-O0", "-g" ]
    env["CCFLAGS_SIZ"] = [ "-Os", "-fomit-frame-pointer", "$CCFLAGS_TUN", "$CCFLAGS_ARCH" ]
    env["CCFLAGS_SPD"] = [ "-O2", "-fomit-frame-pointer", "$CCFLAGS_TUN", "$CCFLAGS_ARCH" ]

    env["CPPDEFINES_CMN"] = []

    env["LINKFLAGS_CMN"] = [ "$_RPATH" ]
    env["LINKFLAGS_DBG"] = []
    env["LINKFLAGS_SIZ"] = [ "-s" ]
    env["LINKFLAGS_SPD"] = [ "-s" ]
    env["LINKFLAGS_WIN"] = []

    env["SHLINKFLAGS"]  = SCons.Util.CLVar ('$LINKFLAGS -shared $_SONAME')
    env["_SONAME"]      = "${_concat (SONAMEPREFIX, SONAME, SONAMESUFFIX, __env__)}"
    env["SONAMEPREFIX"] = "-Wl,-soname,$SHLIBPREFIX"
    env["SONAMESUFFIX"] = "$SHLIBSUFFIX"

    consVars = [ "CCFLAGS", "CPPPATH", "CPPDEFINES",
                 "LIBS", "LIBPATH", "LINKFLAGS" ]
    if env["optim"] == "debug":
        for var in consVars:
            env[var] = [ "$%s_CMN" % var, "$%s_DBG" % var ]
        env.Append (CPPDEFINES = [ "DEBUG" ])
    elif env["optim"] == "speed":
        for var in consVars:
            env[var] = [ "$%s_CMN" % var, "$%s_SPD" % var ]
        env.Append (CPPDEFINES = [ "NDEBUG" ])
    elif env["optim"] == "size":
        for var in consVars:
            env[var] = [ "$%s_CMN" % var, "$%s_SIZ" % var ]
        env.Append (CPPDEFINES = [ "NDEBUG" ])
    elif env["optim"] != "custom":
        raise Exception, "Unknown optimization variable!"

    vars.AddVariables (("tune", "CPU model to tune for (will still work on older CPUs)"),
                       ("arch", "CPU architecture to compile for (won't work on older CPUs)"))
    vars.Update (env)
    tune = env.get ("tune", "")
    if tune != "":
        env["CCFLAGS_TUN"] = "-mtune=%s" % tune
    arch = env.get ("arch", "")
    if arch != "":
        env["CCFLAGS_ARCH"] = "-march=%s" % arch
    
    import sconstools
    sconstools.setupMPatrol (vars, env, [ "bfd", "iberty" ])

    # Setup installation paths
    env["DATA_PATH"]    = "${PREFIX}/share/${PACKAGE}"
    env["DOC_PATH"]     = "${PREFIX}/share/doc/${PACKAGE}"
    env["HEADER_PATH"]  = "${PREFIX}/include/${PACKAGE}"
    env["LIBRARY_PATH"] = "${PREFIX}/lib"
    env["PROGRAM_PATH"] = "${PREFIX}/bin"

    if not env["DEST_DIR"]:
        class LdPostAction:
            def __init__ (self, env):
                import re
                self.action = env.Action ("$$LDCONFIGCOM", "$$LDCONFIGSTR")
                self.exp = re.compile (r"lib.*\.so$")

            def needed (self, env, nodes):
                import SCons.Util
                if SCons.Util.is_Sequence (nodes):
                    for n in nodes:
                        if self.needed (env, n):
                            return True
                elif self.exp.match (nodes.name):
                    return True
                return False

        env["LIBRARY_POSTACTION"] = LdPostAction (env)
        env["LDCONFIGCOM"] = "/sbin/ldconfig -l $TARGET"
        if not env["verbose"]:
            env["LDCONFIGSTR"] = tools.makeStandardCommandString ("Registering ${TARGET}...")
        else:
            env["LDCONFIGSTR"] = tools.makeVerboseCommandString ("Registering ${TARGET} with:",
                                                                 "${LDCONFIGCOM}")
