import SCons.Defaults
import SCons.Tool
import SCons.Util

def setGenericGccTarget (env, vars, prefix=""):
    # C compiler
    staticObj, sharedObj = SCons.Tool.createObjBuilders (env)

    staticObj.add_action ('.c', SCons.Defaults.CAction)
    staticObj.add_emitter ('.c', SCons.Defaults.StaticObjectEmitter)

    env['CC']           = "%sgcc" % prefix
    env['CCFLAGS']      = SCons.Util.CLVar('-c')
    env['CCCOM']        = '$CC $CCFLAGS $CPPFLAGS $_CPPDEFFLAGS $_CPPINCFLAGS -c -o $TARGET $SOURCES'
    env['CFILESUFFIX']  = '.c'
    env['CXX']          = "%sg++" % prefix
    env['CXXFLAGS']     = [ "$CCFLAGS" ]
    env['CXXCOM']       = '$CXX $CXXFLAGS $CPPFLAGS $_CPPDEFFLAGS $_CPPINCFLAGS -c -o $TARGET $SOURCES'
    env['CXXFILESUFFIX'] = '.cc'
    env['CPPDEFPREFIX'] = '-D'
    env['CPPDEFSUFFIX'] = ''
    env['INCPREFIX']    = '-I'
    env['INCSUFFIX']    = ''

    # Static libraries generation
    SCons.Tool.createStaticLibBuilder(env)

    env['AR']           = "%sar" % prefix
    env['ARCOM']        = '$AR -r $ARFLAGS $TARGET $SOURCES'
    env['ARFLAGS']      = SCons.Util.CLVar()
    env['LIBPREFIX']    = 'lib'
    env['LIBSUFFIX']    = '.a'

    # Shared libraries generation
    SCons.Tool.createSharedLibBuilder (env)

    env["SHLINKFLAGS"]  = SCons.Util.CLVar ('$LINKFLAGS -shared $_SONAME')
    env["_SONAME"]      = "${_concat (SONAMEPREFIX, SONAME, SONAMESUFFIX, __env__)}"
    env["SONAMEPREFIX"] = "-Wl,-soname,$SHLIBPREFIX"
    env["SONAMESUFFIX"] = "$SHLIBSUFFIX"

    # Assembler
    staticObj.add_action ('.s', SCons.Defaults.ASAction)
    staticObj.add_emitter ('.s', SCons.Defaults.StaticObjectEmitter)
    env['AS']           = "%sas" % prefix
    env['ASFLAGS']      = SCons.Util.CLVar()
    env['ASCOM']        = '$AS $ASFLAGS -o $TARGET $SOURCES'
    
    # Some setting from the platform also have to be overridden:
    env['OBJSUFFIX']    = '.o'

    # Setup standard flags
    env["CCFLAGS_CMN"] = [ "-Wall", "--pedantic", "-Wextra", "-Wno-long-long" ]
    env["CCFLAGS_ANS"] = [ "-ansi" ]
    env["CCFLAGS_DBG"] = [ "-O0", "-g" ]
    env["CCFLAGS_SIZ"] = [ "-Os" ]
    env["CCFLAGS_SPD"] = [ "-O3" ]

    env["CPPDEFINES_CMN"] = []

    env["LINKFLAGS_CMN"] = [ "$_RPATH" ]
    env["LINKFLAGS_DBG"] = []
    env["LINKFLAGS_SIZ"] = [ "-s" ]
    env["LINKFLAGS_SPD"] = [ "-s" ]

    consVars = [ "CCFLAGS", "CPPPATH", "CPPDEFINES",
                 "LIBS", "LIBPATH", "LINKFLAGS" ]
    if env["optim"] == "debug":
        for var in consVars:
            env[var] = [ "$%s_CMN" % var, "$%s_DBG" % var ]
        env.Append (CPPDEFINES = [ "DEBUG" ])
    elif env["optim"] == "speed":
        for var in consVars:
            env[var] = [ "$%s_CMN" % var, "$%s_SPD" % var ]
        env.Append (CPPDEFINES = [ "NDEBUG" ])
    elif env["optim"] == "size":
        for var in consVars:
            env[var] = [ "$%s_CMN" % var, "$%s_SIZ" % var ]
        env.Append (CPPDEFINES = [ "NDEBUG" ])
    elif env["optim"] != "custom":
        raise Exception, "Unknown optimization option!"
