import _gcc

def setImx31Target (env, vars):
    # Add options
    if vars:
        from SCons.Variables import EnumVariable
        vars.AddVariables (("arm_cpu", "Target CPU"),
                           EnumVariable ("arm_mode", "Compilation mode",
                                         "arm", [ "arm", "thumb" ]),
                           ("imx31_base_path",
                            "Base path where the system libs and includes are located"),
                           ("gnu_prefix", "Target toolchain prefix",
                            "arm-none-linux-gnueabi-"))
        vars.Update (env)

        # Setup the generic gcc toolchain
        _gcc.setGenericGccTarget (env, vars, env["gnu_prefix"])

        if env.has_key ("arm_cpu"):
            env.Append (CCFLAGS = [ "-mcpu=$arm_cpu" ])

        if env["arm_mode"] == "arm":
            pass
        elif env["arm_mode"] == "thumb":
            env.Append (CCFLAGS = [ "-mthumb" ])
        else:
            raise Exception, "Unknown compilation mode: '%s'" % env["arm_mode"]

        imx31BasePath = env.get ("imx31_base_path", None)
        if imx31BasePath:
            env.Append (CPPPATH = [ "%s/include" % imx31BasePath ],
                        LIBPATH = [ "%s/lib" % imx31BasePath ],
                        LINKFLAGS = [ "-Wl,--rpath-link", "-Wl,%s/lib" % imx31BasePath ])
    else:
        # Setup the generic gcc toolchain
        _gcc.setGenericGccTarget (env, vars)

    # Setup installation paths
    env["DATA_PATH"]    = "${PREFIX}/share/${PACKAGE}"
    env["DOC_PATH"]     = "${PREFIX}/share/doc/${PACKAGE}"
    env["HEADER_PATH"]  = "${PREFIX}/include/${PACKAGE}"
    env["LIBRARY_PATH"] = "${PREFIX}/lib"
    env["PROGRAM_PATH"] = "${PREFIX}/bin"

def register (targets):
    if targets.has_key ("imx31"):
        print "WARNING: Multiple registration for the imx31 target"
    else:
        targets["imx31"] = setImx31Target
