"""
Distutils setup script for the sconstools package.
"""
from distutils.core import setup

# Find the version number (strongly inspired by Mercurial's setup.py)
import os
import subprocess   as sp
import time
import sys
if os.path.isdir ('.hg'):
    hgexe = "hg.bat" if sys.platform == "win32" else "hg"
    env = { 'HGRCPATH': '',
            'LANGUAGE': 'C',
            'PATH': os.environ['PATH'] }
    if 'LD_LIBRARY_PATH' in os.environ:
        env['LD_LIBRARY_PATH'] = os.environ['LD_LIBRARY_PATH']
    if 'PYTHONPATH' in os.environ:
        env['PYTHONPATH'] = os.environ['PYTHONPATH']
    if 'SystemRoot' in os.environ:
        # Copy SystemRoot into the custom environment for Python 2.6
        # under Windows. Otherwise, the subprocess will fail with
        # error 0xc0150004. See: http://bugs.python.org/issue3440
        env['SystemRoot'] = os.environ['SystemRoot']
    l = (sp.Popen ([ hgexe, "id", "-i", "-t" ],
                   shell = False, stdout = sp.PIPE, env = env)
         .stdout.read().split())
    while (len (l) > 1) and (l[-1][0].isalpha()): # Remove non-numbered tags
        l.pop()
    if len (l) > 1: # Tag found
        version = l[-1]
        if l[0].endswith ('+'): # Propagate the dirty status to the tag
            version += '+'
    elif len (l) == 1: # No tag found
        version = (sp.Popen ([ hgexe, "parents", "--template", "{latesttag}+{latesttagdistance}-" ],
                             shell = False, stdout = sp.PIPE, env = env)
                   .stdout.read()
                   + l[0])
    if version.endswith ('+'):
        version += time.strftime ('%Y%m%d')
elif os.path.exists ('.hg_archival.txt'):
    kw = dict ([ [ t.strip() for t in l.split (':', 1) ]
                 for l in open ('.hg_archival.txt') ])
    if 'tag' in kw:
        version =  kw['tag']
    elif 'latesttag' in kw:
        version = '%(latesttag)s+%(latesttagdistance)s-%(node).12s' % kw
    else:
        version = kw.get('node', '')[:12]
else:
    version = time.strftime ('unknown-%Y%m%d')

def findPackages (root = ""):
    def splitPath (path):
        result = []
        head, tail = os.path.split (path)
        while head:
            result.append (tail)
            head, tail = os.path.split (head)
        result.reverse()
        return result
    packages = []
    for dirpath, dirnames, filenames in os.walk (root):
        if os.path.exists (os.path.join (dirpath, "__init__.py")):
            packages.append (".".join (splitPath (dirpath)))
    return packages

setup (name                 = 'sconstools',
       version              = version,
       license              = 'GPL v2',
       author               = 'Jerome M. Berger',
       author_email         = 'jeberger@free.fr',
       data_files           = [ ("share/sconstools", [ "SConstruct" ]),
                                ("share/sconstools/doc", [ "doc/userdoc.txt" ]) ],
       description          = 'Scripts to enhance the functionality of SCons.',
       packages             = findPackages ("sconstools"),
       package_dir          = { "sconstools": "sconstools/sconstools" },
       platforms            = 'any',
       scripts              = [ "scripts/sconstools-setup",
                                "scripts/sconstools-setup.bat" ]
       )
